@@ -21,12 +21,13 @@
 
 #include "config.h"
 
+#undef G_LOG_DOMAIN
+#define G_LOG_DOMAIN "operation"
+
 #include "seahorse-gpgme.h"
 
 #include "seahorse-common.h"
 
-#define DEBUG_FLAG SEAHORSE_DEBUG_OPERATION
-#include "libseahorse/seahorse-debug.h"
 #include "libseahorse/seahorse-util.h"
 
 #include <glib/gi18n.h>
@@ -318,7 +319,7 @@ seahorse_gpgme_gsource_dispatch (GSource *gsource,
 	for (l = watches; l != NULL; l = g_list_next (l)) {
 		watch = l->data;
 		if (watch->registered && watch->poll_fd.revents) {
-			seahorse_debug ("GPGME OP: io for GPGME on %d", watch->poll_fd.fd);
+			g_debug ("GPGME OP: io for GPGME on %d", watch->poll_fd.fd);
 			g_assert (watch->fnc);
 			watch->poll_fd.revents = 0;
 			(watch->fnc) (watch->fnc_data, watch->poll_fd.fd);
@@ -355,7 +356,7 @@ register_watch (WatchData *watch)
 	if (watch->registered)
 		return;
 
-	seahorse_debug ("GPGME OP: registering watch %d", watch->poll_fd.fd);
+	g_debug ("GPGME OP: registering watch %d", watch->poll_fd.fd);
 
 	watch->registered = TRUE;
 	g_source_add_poll (watch->gsource, &watch->poll_fd);
@@ -367,7 +368,7 @@ unregister_watch (WatchData *watch)
 	if (!watch->registered)
 		return;
 
-	seahorse_debug ("GPGME OP: unregistering watch %d", watch->poll_fd.fd);
+	g_debug ("GPGME OP: unregistering watch %d", watch->poll_fd.fd);
 
 	watch->registered = FALSE;
 	g_source_remove_poll (watch->gsource, &watch->poll_fd);
@@ -385,7 +386,7 @@ on_gpgme_add_watch (void *user_data,
 	SeahorseGpgmeGSource *gpgme_gsource = user_data;
 	WatchData *watch;
 
-	seahorse_debug ("PGPOP: request to register watch %d", fd);
+	g_debug ("PGPOP: request to register watch %d", fd);
 
 	watch = g_new0 (WatchData, 1);
 	watch->registered = FALSE;
@@ -437,7 +438,7 @@ on_gpgme_event (void *user_data,
 	case GPGME_EVENT_START:
 		gpgme_gsource->busy = TRUE;
 		gpgme_gsource->finished = FALSE;
-		seahorse_debug ("PGPOP: start event");
+		g_debug ("PGPOP: start event");
 
 		/* Since we weren't supposed to register these before, do it now */
 		for (l = gpgme_gsource->watches; l != NULL; l= g_list_next (l))
@@ -448,7 +449,7 @@ on_gpgme_event (void *user_data,
 	case GPGME_EVENT_DONE:
 		gpgme_gsource->busy = FALSE;
 		gerr = (gpgme_error_t *)type_data;
-		seahorse_debug ("PGPOP: done event (err: %d)", *gerr);
+		g_debug ("PGPOP: done event (err: %d)", *gerr);
 
 		/* Make sure we have no extra watches left over */
 		for (l = gpgme_gsource->watches; l != NULL; l = g_list_next (l))
