@@ -38,9 +38,6 @@
 
 #include <libsoup/soup.h>
 
-#define DEBUG_FLAG SEAHORSE_DEBUG_HKP
-#include "libseahorse/seahorse-debug.h"
-
 /**
  * SECTION: seahorse-hkp-source
  * @short_description: Implements the HKP (HTTP Keyserver protocol) Source object
@@ -118,6 +115,7 @@ create_hkp_soup_session (void)
 	SoupSession *session;
 #if WITH_DEBUG
 	SoupLogger *logger;
+	const gchar *env;
 #endif
 
         session = soup_session_async_new_with_options (SOUP_SESSION_ADD_FEATURE_BY_TYPE,
@@ -126,7 +124,8 @@ create_hkp_soup_session (void)
 
 
 #if WITH_DEBUG
-	if (seahorse_debugging) {
+        env = g_getenv ("G_MESSAGES_DEBUG");
+        if (env && strstr (env, "seahorse")) {
 		logger = soup_logger_new (SOUP_LOGGER_LOG_BODY, -1);
 		soup_session_add_feature (session, SOUP_SESSION_FEATURE (logger));
 		g_object_unref (logger);
@@ -245,6 +244,21 @@ parse_hkp_date (const gchar *text)
     return stamp == (time_t)-1 ? 0 : stamp;
 }
 
+static const gchar *
+get_fingerprint_string (const gchar *line)
+{
+	const gchar *p;
+
+	p = line;
+	while (*p && g_ascii_isspace (*p))
+		p++;
+
+	if (g_ascii_strncasecmp (p, "fingerprint=", 12) == 0)
+		return p + 12;
+	else
+		return NULL;
+}
+
 /**
 * response: The HKP server response to parse
 *
@@ -268,6 +282,7 @@ parse_hkp_index (const gchar *response)
 	gchar *line, *t;
     
 	SeahorsePgpKey *key = NULL;
+	SeahorsePgpSubkey *subkey_with_id = NULL;
 	GList *keys = NULL;
 	GList *subkeys = NULL;
 	GList *uids = NULL;
@@ -276,11 +291,10 @@ parse_hkp_index (const gchar *response)
 	lines = g_strsplit (response, "\n", 0);
     
 	for (l = lines; *l; l++) {
-
 		line = *l;	
 		dehtmlize (line);
 
-		seahorse_debug ("%s", line);
+		g_debug ("%s", line);
 
 		/* Start a new key */
 		if (g_ascii_strncasecmp (line, "pub ", 4) == 0) {
@@ -341,6 +355,7 @@ parse_hkp_index (const gchar *response)
 					seahorse_object_list_free (subkeys);
 					seahorse_pgp_key_realize (SEAHORSE_PGP_KEY (key));
 					uids = subkeys = NULL;
+					subkey_with_id = NULL;
 					key = NULL;
 				}
 
@@ -351,9 +366,12 @@ parse_hkp_index (const gchar *response)
 				/* Add all the info to the key */
 				subkey = seahorse_pgp_subkey_new ();
 				seahorse_pgp_subkey_set_keyid (subkey, fpr);
+				subkey_with_id = subkey;
+
 				fingerprint = seahorse_pgp_subkey_calc_fingerprint (fpr);
 				seahorse_pgp_subkey_set_fingerprint (subkey, fingerprint);
 				g_free (fingerprint);
+
 				seahorse_pgp_subkey_set_flags (subkey, flags);
 				seahorse_pgp_subkey_set_created (subkey, parse_hkp_date (v[1]));
 				seahorse_pgp_subkey_set_length (subkey, strtol (v[0], NULL, 10));
@@ -383,9 +401,29 @@ parse_hkp_index (const gchar *response)
             
 			/* TODO: Implement signatures */
             
-		} 
+		} else if (key && subkey_with_id) {
+			const char *fingerprint_str;
+
+			fingerprint_str = get_fingerprint_string (line);
+
+			if (fingerprint_str != NULL) {
+				char *pretty_fingerprint;
+
+				pretty_fingerprint = seahorse_pgp_subkey_calc_fingerprint (fingerprint_str);
+
+				/* FIXME: we don't check that the fingerprint actually matches the key's ID.
+				 * We also don't validate the fingerprint at all; the keyserver may have returned
+				 * some garbage and we don't notice.
+				 */
+
+				if (pretty_fingerprint[0] != 0)
+					seahorse_pgp_subkey_set_fingerprint (subkey_with_id, pretty_fingerprint);
+
+				g_free (pretty_fingerprint);
+			}
+		}
 	}
-    
+
 	g_strfreev (lines);
 
 	if (key) {
@@ -650,6 +688,8 @@ seahorse_hkp_source_search_async (SeahorseServerSource *source,
 		g_hash_table_insert (form, "search", (char *)match);
 	}
 
+	g_hash_table_insert (form, "fingerprint", "on");
+
 	soup_uri_set_query_from_form (uri, form);
 	g_hash_table_destroy (form);
 
