@@ -407,6 +407,7 @@ on_keyserver_search_ok_clicked (GtkButton *button, SeahorseWidget *swidget)
 	KeyserverSelection *selection;
 	const gchar *search;
 	GtkWidget *widget;
+	GtkWindow *parent;
 
 	widget = seahorse_widget_get_widget (swidget, "search-text");
 	g_return_if_fail (widget != NULL);
@@ -422,8 +423,12 @@ on_keyserver_search_ok_clicked (GtkButton *button, SeahorseWidget *swidget)
 	g_settings_set_strv (seahorse_application_settings (NULL), "last-search-servers",
 	                     selection->all ? NULL : (const gchar * const*)selection->uris->pdata);
 
-	/* Open the new result window */
-	seahorse_keyserver_results_show (search);
+	/* Open the new result window; its transient parent is *our* transient
+	 * parent (Seahorse's primary window), not ourselves, as *we* will
+	 * disappear when "OK" is clicked.
+	 */
+	parent = gtk_window_get_transient_for (GTK_WINDOW (seahorse_widget_get_widget (swidget, swidget->name)));
+	seahorse_keyserver_results_show (search, parent);
 
 	free_keyserver_selection (selection);
 	seahorse_widget_destroy (swidget);
