@@ -13,15 +13,15 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __SEAHORSE_KEYSERVER_SYNC_H__
 #define __SEAHORSE_KEYSERVER_SYNC_H__
 
+#include <gtk/gtk.h>
+
 void        seahorse_keyserver_sync             (GList *keys);
 
 
