@@ -44,9 +44,6 @@
 #include "libseahorse/seahorse-object-widget.h"
 #include "libseahorse/seahorse-util.h"
 
-#define DEBUG_FLAG SEAHORSE_DEBUG_KEYS
-#include "libseahorse/seahorse-debug.h"
-
 #include <glib/gi18n.h>
 
 #include <string.h>
@@ -1001,6 +998,7 @@ enum {
 	SUBKEY_OBJECT,
 	SUBKEY_ID,
 	SUBKEY_TYPE,
+	SUBKEY_USAGE,
 	SUBKEY_CREATED,
 	SUBKEY_EXPIRES,
 	SUBKEY_STATUS,
@@ -1009,13 +1007,14 @@ enum {
 };
 
 const GType subkey_columns[] = {
-    G_TYPE_OBJECT,  /* index */
-    G_TYPE_STRING,  /* id */
-    G_TYPE_STRING,  /* created */
-    G_TYPE_STRING,  /* expires */
-    G_TYPE_STRING,  /* status  */
-    G_TYPE_STRING,  /* type */
-    G_TYPE_UINT     /* length*/
+    G_TYPE_OBJECT,  /* SUBKEY_OBJECT */
+    G_TYPE_STRING,  /* SUBKEY_ID */
+    G_TYPE_STRING,  /* SUBKEY_TYPE */
+    G_TYPE_STRING,  /* SUBKEY_USAGE */
+    G_TYPE_STRING,  /* SUBKEY_CREATED */
+    G_TYPE_STRING,  /* SUBKEY_EXPIRES  */
+    G_TYPE_STRING,  /* SUBKEY_STATUS */
+    G_TYPE_UINT     /* SUBKEY_LENGTH */
 };
 
 /* trust combo box list */
@@ -1229,7 +1228,7 @@ setup_details_trust (SeahorseWidget *swidget)
     GtkTreeIter iter;
     GtkCellRenderer *text_cell = gtk_cell_renderer_text_new ();
 
-    seahorse_debug ("KeyProperties: Setting up Trust Combo Box Store");
+    g_debug ("KeyProperties: Setting up Trust Combo Box Store");
 
     object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
     etype = seahorse_object_get_usage (object);
@@ -1281,7 +1280,7 @@ setup_details_trust (SeahorseWidget *swidget)
     
     gtk_combo_box_set_model (GTK_COMBO_BOX (widget), GTK_TREE_MODEL (model));                                        
 
-    seahorse_debug ("KeyProperties: Finished Setting up Trust Combo Box Store");
+    g_debug ("KeyProperties: Finished Setting up Trust Combo Box Store");
 }
 
 static void
@@ -1432,6 +1431,9 @@ do_details (SeahorseWidget *swidget)
         gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget),
                                                      -1, _("Type"), gtk_cell_renderer_text_new (), 
                                                      "text", SUBKEY_TYPE, NULL);
+        gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget),
+                                                     -1, _("Usage"), gtk_cell_renderer_text_new (),
+                                                     "text", SUBKEY_USAGE, NULL);
         gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget),
                                                      -1, _("Created"), gtk_cell_renderer_text_new (), 
                                                      "text", SUBKEY_CREATED, NULL);
@@ -1451,6 +1453,7 @@ do_details (SeahorseWidget *swidget)
 		const gchar *status = NULL;
 		gchar *expiration_date;
 		gchar *created_date;
+		gchar *usage;
 		gulong expires;
 		guint flags;
 		
@@ -1474,20 +1477,24 @@ do_details (SeahorseWidget *swidget)
 			expiration_date = seahorse_util_get_display_date_string (expires);
 
 		created_date = seahorse_util_get_display_date_string (seahorse_pgp_subkey_get_created (subkey));
-        
+
+		usage = seahorse_pgp_subkey_get_usage (subkey);
+
 		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter,  
-		                    SUBKEY_OBJECT, l->data,
-		                    SUBKEY_ID, seahorse_pgp_subkey_get_keyid (l->data),
-		                    SUBKEY_TYPE, seahorse_pgp_subkey_get_algorithm (l->data),
+		gtk_list_store_set (store, &iter,
+		                    SUBKEY_OBJECT, subkey,
+		                    SUBKEY_ID, seahorse_pgp_subkey_get_keyid (subkey),
+		                    SUBKEY_TYPE, seahorse_pgp_subkey_get_algorithm (subkey),
+				    SUBKEY_USAGE, usage,
 		                    SUBKEY_CREATED, created_date,
 		                    SUBKEY_EXPIRES, expiration_date,
-		                    SUBKEY_STATUS,  status, 
+		                    SUBKEY_STATUS, status,
 		                    SUBKEY_LENGTH, seahorse_pgp_subkey_get_length (subkey),
 		                    -1);
-        
+
 		g_free (expiration_date);
 		g_free (created_date);
+		g_free (usage);
 	} 
 }
 
