@@ -14,26 +14,26 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
 
-#include <stdlib.h>
-#include <string.h>
-
-#include <glib/gi18n.h>
+#include "seahorse-server-source.h"
 
 #include "seahorse-hkp-source.h"
 #include "seahorse-ldap-source.h"
 #include "seahorse-pgp-key.h"
-#include "seahorse-server-source.h"
 
 #include "seahorse-common.h"
-#include "seahorse-util.h"
+
+#include "libseahorse/seahorse-util.h"
+
+#include <glib/gi18n.h>
+
+#include <stdlib.h>
+#include <string.h>
 
 /**
  * SECTION:seahorse-server-source
