@@ -14,27 +14,26 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
 
-#include <stdlib.h>
+#include "seahorse-pgp-dialogs.h"
+
+#include "seahorse-combo-keys.h"
+#include "seahorse-pgp-key.h"
+#include "seahorse-pgp-keysets.h"
+
+#include "libseahorse/seahorse-progress.h"
+#include "libseahorse/seahorse-widget.h"
+#include "libseahorse/seahorse-validity.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <glib/gi18n.h>
 
-#include "seahorse-pgp-dialogs.h"
-#include "seahorse-progress.h"
-#include "seahorse-widget.h"
-#include "seahorse-validity.h"
-#include "seahorse-combo-keys.h"
-#include "seahorse-util.h"
-
-#include "pgp/seahorse-pgp-key.h"
-#include "pgp/seahorse-pgp-keysets.h"
+#include <stdlib.h>
 
 SeahorsePgpKey*
 seahorse_signer_get (GtkWindow *parent)
