@@ -15,24 +15,23 @@
  * Lesser General Public License for more details.
  *  
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.  
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
-#include "seahorse-application.h"
+#include "libseahorse/seahorse-application.h"
+#include "libseahorse/seahorse-collection.h"
+#include "libseahorse/seahorse-key-manager-store.h"
+#include "libseahorse/seahorse-progress.h"
+#include "libseahorse/seahorse-util.h"
+
 #include "seahorse-generate-select.h"
 #include "seahorse-import-dialog.h"
 #include "seahorse-key-manager.h"
-#include "seahorse-key-manager-store.h"
 #include "seahorse-sidebar.h"
 
-#include "seahorse-collection.h"
-#include "seahorse-progress.h"
-#include "seahorse-util.h"
-
 #include <glib/gi18n.h>
 
 enum {
@@ -842,8 +841,17 @@ seahorse_key_manager_class_init (SeahorseKeyManagerClass *klass)
 	catalog_class->get_focused_place = seahorse_key_manager_get_focused_place;
 }
 
-void
-seahorse_key_manager_show (void)
+SeahorseKeyManager *
+seahorse_key_manager_show (guint32 timestamp)
 {
-	g_object_new (SEAHORSE_TYPE_KEY_MANAGER, "ui-name", "key-manager", NULL);
+	static SeahorseKeyManager *singleton;
+
+	if (singleton) {
+		gtk_window_present_with_time (GTK_WINDOW (singleton), timestamp);
+		return singleton;
+	} else {
+		singleton = g_object_new (SEAHORSE_TYPE_KEY_MANAGER, "ui-name", "key-manager", NULL);
+		g_object_add_weak_pointer (G_OBJECT (singleton), (gpointer*) &singleton);
+		return singleton;
+	}
 }
