@@ -13,10 +13,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -24,8 +22,9 @@
 #include "seahorse-sidebar.h"
 
 #include "seahorse-common.h"
-#include "seahorse-interaction.h"
-#include "seahorse-util.h"
+
+#include "libseahorse/seahorse-interaction.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <glib/gi18n.h>
 
